@@ -54,10 +54,6 @@ class EWAHSnowflakeUploader(EWAHBaseUploader):
             AND table_name = %(table_name)s
         ORDER BY ordinal_position ASC;
     """
-    _QUERY_SCHEMA_CHANGES_DROP_COLUMN = """
-        ALTER TABLE "{database_name}"."{schema_name}"."{table_name}"
-        DROP COLUMN IF EXISTS "{column_name}" CASCADE;
-    """
     _QUERY_SCHEMA_CHANGES_ADD_COLUMN = """
         ALTER TABLE "{database_name}"."{schema_name}"."{table_name}"
         ADD COLUMN "{column_name}" {column_type};
@@ -295,6 +291,10 @@ class EWAHSnowflakeUploader(EWAHBaseUploader):
                 )
         else:
             update_set_cols = []
+            if load_strategy == EC.LS_INSERT_ADD:
+                # Even if set, ignore primary key during insert!
+                primary_key = []
+
             for col in columns_definition.keys():
                 if not (col in primary_key):
                     update_set_cols += [col]
@@ -306,8 +306,8 @@ class EWAHSnowflakeUploader(EWAHBaseUploader):
                     ON {4}
                     WHEN MATCHED THEN UPDATE
                         SET {5}
-                    WHEN NOT MATCHED THEN INSERT
-                                ({6})
+                    WHEN NOT MATCHED THEN
+                        INSERT  ({6})
                         VALUES  ({7})
                     ;
                 DROP TABLE "{0}"."{1}"."{3}" CASCADE;
